﻿from tabnanny import verbose
from django.db import models

# ====================================================
# Описание работы классов и методов исходника на:
# https://www.interestprograms.ru
# Исходные коды программ и игр
# Автор исходных кодов Клочков Павел
# ====================================================


# Общие поля для моделей приложения
class CommonFields(models.Model):
    id = models.BigAutoField(primary_key=True, auto_created=True)
    name = models.CharField(max_length=300, verbose_name="Название")
    description = models.TextField(null=True, verbose_name="Описание")
    # Данный класс не будет иметь таблицы в базе данных
    class Meta:
        abstract = True


# Типы электронных компонентов
class TypeComponent(CommonFields):
    class Meta:
        verbose_name = "Тип компонентов"
        verbose_name_plural = "Типы компонентов"


# Электронный компонент
class Component(CommonFields):
    # Определение значения свойства db_column="type_id" фиксирует название 
    # поля (столбца) для внешнего ключа. 
    # По умолчанию имя столбца определяется атрибутом класса + постфикс _id,
    # т.е. без определения db_column название столбца было бы type_foreignkey_id.
    # Различность названия атрибута модели и названия столбца созданы 
    # для демонстрации ручного определения названия столбца.
    type_foreignkey = models.ForeignKey(
        "TypeComponent", db_column="type_id", on_delete=models.CASCADE
    )
    price = models.IntegerField()
    class Meta:
        verbose_name = "Компонент"
        verbose_name_plural = "Компоненты"
        